# Schemas

Here you will find the specification for LCAx.
The specification is provided both as JSON Schemas and Python classes with Pydantic.

## LCAx

=== "Python"

    ```python
    {!> schemas/pydantic.py!}
    ```

=== "JSON Schema"

    ```json
    {!> schemas/lcax.schema.json!}
    ```

=== "Rust"

    ```rust
    {!> schemas/project.rs!}
    ```

## Download

**Python**
- [LCAx](./schemas/pydantic.py)

**JSON Schema**
- [LCAx](./schemas/lcax.schema.json)

**Rust**
- [LCAx](./schemas/project.rs)